@@ -149,8 +149,8 @@ about_verb_cb (BonoboUIComponent *uic,
 
 	quick_lounge->about_dialog = gnome_about_new (_("Quick Lounge"), 
 						      VERSION,
-						      _("Copyright \xc2\xa9 2002 Free Software Foundation, Inc."),
-						      _("Organize your favourite applications on the Panel"),
+						      "Copyright \xc2\xa9 2002-2003 Free Software Foundation, Inc.",
+						      _("Organize your favorite applications on the Panel"),
 						      authors,
 						      documenters,
 						      strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -845,7 +845,7 @@ quick_lounge_new_launcher (QuickLounge *quick_lounge,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
 	gnome_window_icon_set_from_file (GTK_WINDOW (widget), GNOME_ICONDIR "quick-lounge-applet.png");
-	gtk_window_set_screen (GTK_WINDOW (dialog), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+	gtk_window_set_screen (GTK_WINDOW (widget), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
 	
 	dialog = GTK_DIALOG (widget);
 
